@@ -1,7 +1,7 @@
 /* libke.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -384,6 +384,11 @@ ke_return_keystring (gint keyID)
 	case XK_BackSpace:rv = g_strdup ("BackSpace");break;
 	case XK_Delete:rv = g_strdup ("Delete");break;
 	case XK_Escape:rv = g_strdup ("Escape");break;
+	case XK_Super_L:rv = g_strdup ("Super_L");break;
+	case XK_Super_R:rv = g_strdup ("Super_R");break;
+	case XK_Hyper_L:rv = g_strdup ("Hyper_L");break;
+	case XK_Hyper_R:rv = g_strdup ("Hyper_R");break;
+	case XK_Menu:rv = g_strdup ("Menu");break;	
         default:
     	    rv = NULL;
     }
@@ -1462,7 +1467,12 @@ long keyecho_keysym[] = {
     XK_Page_Down,
     XK_BackSpace,
     XK_Delete,
-    XK_Escape
+    XK_Escape,
+    XK_Super_L,
+    XK_Super_R,    
+    XK_Hyper_L,
+    XK_Hyper_R,
+    XK_Menu
 };
 
 gchar*
