@@ -883,7 +883,8 @@ static struct
 	{"table-line",		N_("TLI"),	N_("TABLE LINE"),	N_("Table line")		},
 	{"table-columns-header",N_("TCH"),	N_("TABLE COLUMNS HEADER"),N_("Table columns header")	},
 	{"title-bar",		N_("TIT"),	N_("TITLE BAR"),	N_("Title bar")			},
-	{"edit-bar",		N_("EDB"),	N_("EDIT BAR"),		N_("Edit bar")			}
+	{"edit-bar",		N_("EDB"),	N_("EDIT BAR"),		N_("Edit bar")			},
+	{"spread-sheet-cell",	N_("CEL"),	N_("SPREAD SHEET CELL"),N_("Spread sheet cell")		}	
     };
 
 static gint
